<img src="https://github.com/linux-profile/linux-profile-plugin/blob/master/docs/linuxp.png?raw=true">

![GitHub Org's stars](https://img.shields.io/github/stars/linux-profile?label=LinuxProfile&style=flat-square)
![GitHub last commit](https://img.shields.io/github/last-commit/linux-profile/linux-profile-plugin?style=flat-square)
![PyPI](https://img.shields.io/pypi/v/linuxp-plugin)

[![check](https://github.com/linux-profile/linux-profile-plugin/actions/workflows/python-publish-pypi.yml/badge.svg)](https://github.com/linux-profile/linux-profile-plugin/actions/workflows/python-publish-pypi.yml)
[![check](https://github.com/linux-profile/linux-profile-plugin/actions/workflows/python-publish-pypi-test.yml/badge.svg)](https://github.com/linux-profile/linux-profile-plugin/actions/workflows/python-publish-pypi-test.yml)
[![check](https://github.com/linux-profile/linux-profile-plugin/actions/workflows/python-app-code.yml/badge.svg)](https://github.com/linux-profile/linux-profile-plugin/actions/workflows/python-app-code.yml)

---

- **Documentation**: [https://docs.linuxprofile.com](https://docs.linuxprofile.com)
- **Source Code**: [https://github.com/linux-profile/linux-profile-plugin](https://github.com/linux-profile/linux-profile-plugin)

---

## Installation

- **Install - Pypi/PIP**

      pip install -U linuxp-plugin

## Commands

| Command               | Description                                                                           | Docs      |
|:--------------------- |:------------------------------------------------------------------------------------- | :-------: | 
| ``linuxp_plugin hello``      | My custom command.                                                                    | [Link](#) |
| ``linuxp_plugin explore``    | This command shows some settings.                                                     | [Link](#) |


## Commit Style

- ⚙️ FEATURE
- 📝 PEP8
- 📌 ISSUE
- 🪲 BUG
- 📘 DOCS
- 📦 PyPI
- ❤️️ TEST
- ⬆️ CI/CD
- ⚠️ SECURITY

## License

This project is licensed under the terms of the MIT license.
